%% Coefficients for phi

function c = c_N(i,N)
persistent f;
if(isempty(f))
    %Values read from compressor chart (stage 2)
    %a-f represent speed curves, phi pressure ratio and q volume flow
    phi_a = [3.35 3.2 3 2.3];
    q_a = [2100 2400 2680 3200];
    phi_b = [3.15 3 2.7 2.2];
    q_b = [1850 2200 2600 3000];
    phi_c = [3 2.9 2.75 2.3];
    q_c = [1750 2100 2400 2800];
    phi_d = [2.55 2.4 2 1.65];
    q_d = [1600 2050 2500 2800];
    phi_e = [2.2 2 1.7 1.5];
    q_e = [1350 1750 2200 2400];
    phi_f = [1.9 1.7 1.45];
    q_f = [1400 1800 2200];

    %Polynomials for speed curves (a=12867 b=12254 c=12014 d=11029 e=9803 f=9190)
    f_a = polyfit(q_a, phi_a, 2);
    f_b = polyfit(q_b, phi_b, 2);
    f_c = polyfit(q_c, phi_c, 2);
    f_d = polyfit(q_d, phi_d, 2);
    f_e = polyfit(q_e, phi_e, 2);
    f_f = polyfit(q_f, phi_f, 2);

    omega = [12867 12254 12014 11029 9803 9190]; %Speed for the respective curves in rpm
    f = []; %Define an empty matrix for the coefficients for the second polynomial fit
    
    % Third order polynomial fit for the coefficients found above:
    for x=1:1:3
        fx = polyfit(omega,[f_a(x) f_b(x) f_c(x) f_d(x) f_e(x) f_f(x)],3);
        f=[f;fx];
    end
end

c = f(i,1)*N^3 + f(i,2)*N^2 + f(i,3)*N + f(i,4); %Return coefficients  to phi_q

end