%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file initializes all modules in compressor_system.mdl %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global kappa;           %Global constant since used in function phi_T in compressor module

%% Universal constants and boundary conditions
R = 8.314;              %Universal gas constant
M_g = 22e-3;            %Mole weight natural gas
R_g = R/M_g;            %Specific gas constant natural gas
kappa = 1.233;          %Specific heat ratio
p_ov = 85.77e5;         %Output vessel pressure
w_i = 18;               %System input flow
T_i = 85+273;           %System input temperature

%% Simulation parameters
%%Recycle valve step
t_step_rv = 1500;       %Recycle valve step time
rv_start = 0;           %Recycle valve start position
rv_stop = 30;           %Recycle valve stop position

%% Compressor
L_c = 10;               %compressor equivalent length
A_c = (pi*0.25^2)/4;    %compressor duct cross section area
V_c = 3;                %compressor equivalent volume
z_c = 0.891;            %compressibility

p_cd_init = 85.77e5;    %compressor downstream initial pressure
w_c_init = 18;          %compressor initial flow

%% Cooler
U = 773.66;             %Cooler heat transfer coefficient
A = 280.504;            %Cooler area
V_cold = 1.4472;        %Cooler volume cold side
V_w = 1.3126;           %Cooler volume warm side
c_pc = 4186;            %Specific heat cold side
c_vc = c_pc;
c_pw = 2370;            %Specific heat, c_p, warm side
c_vw = 1850;            %Specific heat, c_v, warm side
n = 6;                  %Number of interconnected heat exchanger elements
rho_c = 1.003e3;        %Density cooling medium
rho_w = (34e5*22e-3)/(8.314*(55+273)*0.891);%Average density gas from ideal gas model
m_c = rho_c*V_cold;     %Cooling medium mass inside cooler
m_w = rho_w*V_w;        %Gas mass inside cooler
T_c_in = 20+273;        %Cooling medium temperature
T_c_out_init = 40+273;  %Cooling medium initial outlet temperature
T_w_in_init = 85+273;   %Gas inlet initial temperature
T_w_out_init = 25+273;  %Gas outlet initial temperature
par = struct('U',U,'A',A,'c_pc',c_pc,'c_pw',c_pw,'c_vc',c_vc,'c_vw',c_vw,...
    'n',n,'m_c',m_c,'m_w',m_w,'T_c_i_init',T_c_in,'T_c_o_init',T_c_out_init,...
    'T_w_i_init',T_w_in_init,'T_w_o_init',T_w_out_init);...
    %Define a struct with parameters for cooler s-function
w_cmax = 40;            %Cooling medium max flow
t_tv = 12;              %Cooling valve opening/closing time
T_c_ref = 25+273;       %Cooler reference temperature

%% Scrubber
V_s = 2.0;              %Scrubber volume
p_s_init = 34e5;        %Scrubber initial pressure
T_s_init = 273+25;      %Scrubber initial temperature

%% Upstream vessel
V_uv = 200;             %Upstream vessel volume
p_uv_init = 32.45e5;     %Upstream vessel inital pressure
T_uv_init = 273+85;     %Upstream vessel initial temperature

%% Upstream duct
A_ud = (pi*0.2^2)/4;    %Cross section area upstream duct
L_ud = 100;             %Length upstream duct
w_ud_init = 18;         %Upstream duct initial flow

%% Recycle line
C_v_rv_max = 8.85e-3;   %Recycle valve flow coefficient
t_r_rv = 2;             %Recycle valve rise time
t_td_rv = 1;            %Recycle valve time delay
w_rv_init = 0;          %Recycle valve initial flow
A_rl = pi*0.15^2;       %Recycle line cross section area
L_rl = 100;             %Recycle line length
epsilon_rl = 1e-4;      %Leak flow coefficient

%% Check valve
A_cv = (pi*0.25^2)/4;   %Cross section area check valve duct
L_cv = 200;             %Length check valve duct
w_cv_init = 18;         %check valve initial flow

%% Shaft
K_sh = 10;              %Shaft friction
J_sh = 10;              %Shaft inertia
omega_sh = 1200;        %Compressor initial speed
