%% Universal constants
R = 8.314;          %Universal gas constant
M_gas = 22e-3;      %Molar weight natural gas
M_air = 28.97e-3;   %Molar weight air

%% Ambient conditions
p_in = 101300;      %inlet pressure
p_out = 101300;     %outlet pressure
T_in = 273+18;      %inlet temperature

%% Compressor
z_c = 0.9778;       %Compressibility factor compressor
kappa_c = 1.393;    %Specific heat ratio air at 420K
L_c = 10;           %Duct length
A_c = 0.4;          %Duct cross section area
w_c_init = 56.4;    %Initial mass flow
eta_c = 0.87;       %Efficiency
c_p_comp = 1016;    %Specific heat air at 420K
eta_c_mech = 0.9;   %Mechanical efficiency

%% Gas turbine
eta_gg = 0.9;       %Efficiency
c_p_gg = 1142;      %Specific heat air at 1000K
kappa_gg = 1.336;   %Specific heat ratio air at 1000K
kt_gg = 2.76e-3;    %Flow constant

%% Power turbine
eta_pt = 0.9;       %Efficiency
c_p_pt = 1093;      %Specific heat air at 780K
kappa_pt = 1.357;   %Specific heat ratio air at 780K
kt_pt = 8.66e-3;    %Flow constant

%% Combustor
eta_comb = 1;       %Efficiency
HHV = 42.5e6;       %Higher heat value
V_comb = 10;        %Volume
c_p_comb = 1106;    %Specific heat air at 832K
c_v_comb = c_p_comb - R/M_air; %Specific heat air at 832K
kappa_comb = 1.351; %Specific heat ratio air at 832K
T_comb = 1116;      %Initial temperature
m_comb = (7.15e5*V_comb*M_air)/(R*T_comb); %Initial mass

%% Shaft
J1 = 100;           %Inertia of compressor-gas turbine shaft
J2 = 100;           %Inertia of power turbine-load shaft
omega1 = 754;       %Initial speed shaft 1
omega2 = 529;       %Initial speed shaft 2
K_s1  =0;           %Friction coefficient shaft 1
K_s2 =0;            %Friction coefficient shaft 2

%% Init turbine volume
V_tv = 5;           %Volume between turbines
p_tv = 2.15e5;      %Initial pressure between turbines
T_tv = 849;         %Initial temperature between turbines
kappa_tv = 1.349;   %Specific heat ratio air at 850K